@@ -1,14 +1,13 @@
 #[macro_use]
-extern crate log;
+extern crate tracing;
 
 use binance::account::*;
 use binance::api::*;
 use binance::config::Config;
 use binance::errors::Error as BinanceLibError;
-use binance::futures::rest_model::SymbolPrice;
 use binance::general::*;
 use binance::market::*;
-use binance::rest_model::{OrderSide, OrderType, TimeInForce};
+use binance::rest_model::{OrderSide, OrderType, SymbolPrice, TimeInForce};
 use env_logger::Builder;
 
 #[tokio::main]
@@ -208,7 +207,7 @@ async fn market_data() {
     }
 
     // 10 latest (aggregated) trades
-    match market.get_agg_trades("BNBETH", None, None, None, Some(10)) {
+    match market.get_agg_trades("BNBETH", None, None, None, Some(10)).await {
         Ok(trades) => {
             let trade = &trades[0]; // You need to iterate over them
             println!(
